/*
 *****************************************************
 *
 *  SaVi by Lloyd Wood (lloydwood@users.sourceforge.net),
 *          Patrick Worfolk (worfolk@alum.mit.edu) and
 *          Robert Thurman.
 *
 *  Copyright (c) 1997 by The Geometry Center.
 *  Also Copyright (c) 2006 by Lloyd Wood.
 *
 *  This file is part of SaVi.  SaVi is free software;
 *  you can redistribute it and/or modify it only under
 *  the terms given in the file COPYRIGHT which you should
 *  have received along with this file.  SaVi may be
 *  obtained from:
 *  http://savi.sourceforge.net/
 *  http://www.geom.uiuc.edu/locate/SaVi
 *
 *****************************************************
 *
 * coverage_vis.h
 *
 * $Id: coverage_vis.h,v 1.16 2006/04/30 14:17:23 lloydwood Exp $
 */

#ifndef _COVERAGE_VIS_H_
#define _COVERAGE_VIS_H_

#include "stats_utils.h"
#include "Satellite.h"

/*
 * Indices to be inserted in the foreground array drawn over coverage.
 */
enum {
    COVERAGE_AREA_CI = 0,
    MAP_OUTLINE_CI,
    PROJECT_TRACKS_CI,
    SPECIAL_PROJECT_TRACKS_CI,
    GROUND_TRACKS_CI,
    GROUND_TRACKS_CROSS_CI,
    SPECIAL_GROUND_TRACKS_CI,
    SPECIAL_GROUND_TRACKS_CROSS_CI
};

void write_image_to_file(char *name);

int coverage_tempfile_created(void);

void coverage_color_copy(void);
int coverage_uses_zlib(void);
unsigned int coverage_custom_height_valid(int map_view_height);
void image_init(grid *g);
void update_display(int projection, grid *g, int coverage_flag,
			   int tracks_flag, int project_tracks_flag);
void coverage_send_static_file(void);
void coverage_send_scratchfile(void);
void coverage_tempfile_cleanup(void);
void reset_foreground(int projection, grid *g);
void clear_intensity(grid *g);
void clear_interval(grid * g);
void decay_interval(grid *g);
void tracks_to_foreground(const Satellite_list SL, int projection, grid *g,
			  unsigned int color_index, const CentralBody *pcb);
void track_to_foreground(Satellite s, int projection, grid *g,
			 unsigned int color_index, const CentralBody *pcb);

#endif
/* !_COVERAGE_VIS_H */


